@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  Image compression/decompression methods.
+  MagickCore image compression/decompression methods.
 */
-#ifndef _MAGICK_COMPRESS_H
-#define _MAGICK_COMPRESS_H
+#ifndef _MAGICKCORE_COMPRESS_H
+#define _MAGICKCORE_COMPRESS_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -24,18 +24,11 @@ extern "C" {
 
 extern MagickExport MagickBooleanType
   HuffmanDecodeImage(Image *),
-  HuffmanEncodeImage0(const ImageInfo *,Image *,int),
   HuffmanEncodeImage(const ImageInfo *,Image *),
-  Huffman2DEncodeImage0(const ImageInfo *,Image *,int),
   Huffman2DEncodeImage(const ImageInfo *,Image *),
-  JPEGEncodeImage0(const ImageInfo *,Image *,int),
-  JPEGEncodeImage(const ImageInfo *,Image *),
-  LZWEncodeImage0(Image *,const size_t,unsigned char *,int),
   LZWEncodeImage(Image *,const size_t,unsigned char *),
-  PackbitsEncodeImage0(Image *,const size_t,unsigned char *,int),
   PackbitsEncodeImage(Image *,const size_t,unsigned char *),
-  ZLIBEncodeImage0(Image *,const size_t,const unsigned long,unsigned char *,int),
-  ZLIBEncodeImage(Image *,const size_t,const unsigned long,unsigned char *);
+  ZLIBEncodeImage(Image *,const size_t,unsigned char *);
 
 extern MagickExport void
   Ascii85Encode(Image *,const unsigned char),
