@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -27,9 +27,9 @@ extern WandExport ChannelStatistics
   *MagickGetImageChannelStatistics(MagickWand *);
 
 extern WandExport char
-  *MagickGetImageAttribute(MagickWand *,const char *),
   *MagickGetImageFilename(MagickWand *),
   *MagickGetImageFormat(MagickWand *),
+  *MagickGetImageProperty(MagickWand *,const char *),
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
@@ -50,6 +50,7 @@ extern WandExport double
   MagickGetImageTotalInkDensity(MagickWand *);
 
 extern WandExport Image
+  *MagickDestroyImage(Image *),
   *GetImageFromMagickWand(MagickWand *);
 
 extern WandExport ImageType
@@ -58,6 +59,9 @@ extern WandExport ImageType
 extern WandExport InterlaceType
   MagickGetImageInterlaceScheme(MagickWand *);
 
+extern WandExport InterpolatePixelMethod
+  MagickGetImageInterpolateMethod(MagickWand *);
+
 extern WandExport MagickBooleanType
   MagickAdaptiveBlurImage(MagickWand *,const double,const double),
   MagickAdaptiveBlurImageChannel(MagickWand *,const ChannelType,const double,
@@ -117,6 +121,8 @@ extern WandExport MagickBooleanType
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
+  MagickExtentImage(MagickWand *,const unsigned long,const unsigned long,
+    const long,const long),
   MagickFlipImage(MagickWand *),
   MagickFlopImage(MagickWand *),
   MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
@@ -141,6 +147,7 @@ extern WandExport MagickBooleanType
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
+  MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
     long *),
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
@@ -156,9 +163,10 @@ extern WandExport MagickBooleanType
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
+  MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
-  MagickMatteFloodfillImage(MagickWand *,const Quantum,const double,
+  MagickMatteFloodfillImage(MagickWand *,const double,const double,
     const PixelWand *,const long,const long),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
@@ -173,15 +181,19 @@ extern WandExport MagickBooleanType
   MagickNormalizeImage(MagickWand *),
   MagickNormalizeImageChannel(MagickWand *,const ChannelType),
   MagickOilPaintImage(MagickWand *,const double),
+  MagickOrderedPosterizeImage(MagickWand *,const char *),
+  MagickOrderedPosterizeImageChannel(MagickWand *,const ChannelType,
+    const char *),
   MagickPaintOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
   MagickPaintOpaqueImageChannel(MagickWand *,const ChannelType,
     const PixelWand *,const PixelWand *,const double),
-  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const Quantum,
+  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const double,
     const double),
   MagickPingImage(MagickWand *,const char *),
   MagickPingImageBlob(MagickWand *,const void *,const size_t),
   MagickPingImageFile(MagickWand *,FILE *),
+  MagickPolaroidImage(MagickWand *,const DrawingWand *,const double),
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
@@ -200,6 +212,7 @@ extern WandExport MagickBooleanType
   MagickReadImage(MagickWand *,const char *),
   MagickReadImageBlob(MagickWand *,const void *,const size_t),
   MagickReadImageFile(MagickWand *,FILE *),
+  MagickRecolorImage(MagickWand *,const unsigned long,const double *),
   MagickReduceNoiseImage(MagickWand *,const double),
   MagickRemoveImage(MagickWand *),
   MagickResampleImage(MagickWand *,const double,const double,const FilterTypes,
@@ -215,13 +228,13 @@ extern WandExport MagickBooleanType
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
-  MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetImageBias(MagickWand *,const double),
   MagickSetImageBluePrimary(MagickWand *,const double,const double),
   MagickSetImageBorderColor(MagickWand *,const PixelWand *),
   MagickSetImageChannelDepth(MagickWand *,const ChannelType,
     const unsigned long),
+  MagickSetImageClipMask(MagickWand *,const MagickWand *),
   MagickSetImageColormapColor(MagickWand *,const unsigned long,
     const PixelWand *),
   MagickSetImageCompose(MagickWand *,const CompositeOperator),
@@ -237,14 +250,19 @@ extern WandExport MagickBooleanType
   MagickSetImageFilename(MagickWand *,const char *),
   MagickSetImageFormat(MagickWand *,const char *),
   MagickSetImageInterlaceScheme(MagickWand *,const InterlaceType),
+  MagickSetImageInterpolateMethod(MagickWand *,
+    const InterpolatePixelMethod),
   MagickSetImageIterations(MagickWand *,const unsigned long),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
+  MagickSetImageOpacity(MagickWand *,const double),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
+  MagickResetImagePage(MagickWand *,const char *),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
   MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
+  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -252,7 +270,6 @@ extern WandExport MagickBooleanType
   MagickSetImageTicksPerSecond(MagickWand *,const unsigned long),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
   MagickShadeImage(MagickWand *,const MagickBooleanType,const double,const 
     double),
@@ -299,9 +316,6 @@ WandExport MagickProgressMonitor
   MagickSetImageProgressMonitor(MagickWand *,const MagickProgressMonitor,
     void *);
 
-extern WandExport MagickSizeType
-  MagickGetImageSize(MagickWand *);
-
 extern WandExport MagickWand
   *MagickAppendImages(MagickWand *,const MagickBooleanType),
   *MagickAverageImages(MagickWand *),
@@ -317,6 +331,7 @@ extern WandExport MagickWand
   *MagickFxImage(MagickWand *,const char *),
   *MagickFxImageChannel(MagickWand *,const ChannelType,const char *),
   *MagickGetImage(MagickWand *),
+  *MagickGetImageClipMask(MagickWand *),
   *MagickGetImageRegion(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   *MagickMorphImages(MagickWand *,const unsigned long),
@@ -366,7 +381,8 @@ extern WandExport VirtualPixelMethod
   Deprecated methods.
 */
 extern WandExport char
-  *MagickDescribeImage(MagickWand *);
+  *MagickDescribeImage(MagickWand *),
+  *MagickGetImageAttribute(MagickWand *,const char *);
 
 extern WandExport long
   MagickGetImageIndex(MagickWand *);
@@ -374,18 +390,25 @@ extern WandExport long
 extern WandExport MagickBooleanType
   MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
+  MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageIndex(MagickWand *,const long),
   MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
-  MagickTransparentImage(MagickWand *,const PixelWand *,const Quantum,
+  MagickTransparentImage(MagickWand *,const PixelWand *,const double,
     const double);
 
 extern WandExport MagickWand
   *MagickRegionOfInterestImage(MagickWand *,const unsigned long,
-	  const unsigned long,const long,const long);
+    const unsigned long,const long,const long);
+
+extern WandExport MagickSizeType
+  MagickGetImageSize(MagickWand *);
 
 extern WandExport unsigned char
   *MagickWriteImageBlob(MagickWand *,size_t *);
 
+extern WandExport VirtualPixelMethod
+  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
